USE [multiMaxTxn]
GO


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [dbo].[vwCardTransactionsTimeWindow]
AS
	SELECT        
		TxnID, DeviceID, WhereName, CardID, LastName, DateTimeOfTxn,
		/** Change the number of windows below as appopriate, default is set to 10 minutes each side **/
		DATEADD(Minute, -10, DateTimeOfTxn) AS [Before], 
		DATEADD(Minute, 10, DateTimeOfTxn) AS [After], 
		FirstName, CardNumber, ResponseMnemonic, TxnConditionName, DeviceNumber, 
		AlarmEventType, DeviceType, NumberRepeats, CompanyID, CompanyName, LastName + N', ' + FirstName AS CardHolder
	FROM 
		multiMAXTxn.dbo.AlarmEventTransactionTable
	WHERE        
		(CardID <> 0) 
		AND
		/** Change the Date below to reduce the number of rows being returned to improve performance, default is set to 1st January 2020 **/
		DateTimeOfTxn >= '2020-01-01'
GO


CREATE VIEW [dbo].[vwCardTransactionsTimeWindow_Matched]
AS
SELECT        dbo.vwCardTransactionsTimeWindow.DeviceID AS Source_DeviceID, dbo.vwCardTransactionsTimeWindow.WhereName AS Source_WhereName, dbo.vwCardTransactionsTimeWindow.CardID AS Source_CardID, 
                         dbo.vwCardTransactionsTimeWindow.LastName AS Source_LastName, dbo.vwCardTransactionsTimeWindow.DateTimeOfTxn AS Source_DateTimeOfTxn, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.DateTimeOfTxn AS Related_DateTimeOfTxn, dbo.vwCardTransactionsTimeWindow.CardHolder AS Source_CardHolder, 
                         dbo.vwCardTransactionsTimeWindow.FirstName AS Source_FirstName, dbo.vwCardTransactionsTimeWindow.CardNumber AS Source_CardNumber, 
                         dbo.vwCardTransactionsTimeWindow.ResponseMnemonic AS Source_ResponseMnemonic, dbo.vwCardTransactionsTimeWindow.TxnConditionName AS Source_TxnConditionName, 
                         dbo.vwCardTransactionsTimeWindow.DeviceNumber AS Source_DeviceNumber, dbo.vwCardTransactionsTimeWindow.AlarmEventType AS Source_AlarmEventType, 
                         dbo.vwCardTransactionsTimeWindow.DeviceType AS Source_DeviceType, dbo.vwCardTransactionsTimeWindow.CompanyID AS Source_CompanyID, 
                         dbo.vwCardTransactionsTimeWindow.CompanyName AS Source_CompanyName, dbo.vwCardTransactionsTimeWindow.Before AS Source_BeforeTime, 
                         dbo.vwCardTransactionsTimeWindow.After AS Source_AfterTime,  
                         dbo.vwCardTransactionsTimeWindow.TxnID AS SourceTxnID, multiMAXTxn.dbo.AlarmEventTransactionTable.TxnID AS Related_TxnID, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.DeviceNumber AS Related_DeviceNumber, multiMAXTxn.dbo.AlarmEventTransactionTable.AlarmEventType AS Related_AlarmEventType, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.DeviceID AS Related_DeviceID, multiMAXTxn.dbo.AlarmEventTransactionTable.DeviceType AS Related_DeviceType, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.CompanyID AS Related_CompanyID, multiMAXTxn.dbo.AlarmEventTransactionTable.CompanyName AS Related_CompanyName, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.WhereName AS Related_WhereName, multiMAXTxn.dbo.AlarmEventTransactionTable.ResponseMnemonic AS Related_ResponseMnemonic, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.TxnConditionName AS Related_TxnConditionName, multiMAXTxn.dbo.AlarmEventTransactionTable.CardNumber AS Related_CardNumber, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.FirstName AS Related_FirstName, multiMAXTxn.dbo.AlarmEventTransactionTable.LastName AS Related_LastName, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.CommentText AS Related_CommentText, multiMAXTxn.dbo.AlarmEventTransactionTable.CardID AS Related_CardID, 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.LastName + N', ' + multiMAXTxn.dbo.AlarmEventTransactionTable.FirstName AS Related_CardHolder, DATEDIFF(minute, 
                         dbo.vwCardTransactionsTimeWindow.DateTimeOfTxn, multiMAXTxn.dbo.AlarmEventTransactionTable.DateTimeOfTxn) AS TimeApart
FROM            multiMAXTxn.dbo.AlarmEventTransactionTable RIGHT OUTER JOIN
                         dbo.vwCardTransactionsTimeWindow ON 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.DeviceID = dbo.vwCardTransactionsTimeWindow.DeviceID
WHERE        (multiMAXTxn.dbo.AlarmEventTransactionTable.DateTimeOfTxn >= dbo.vwCardTransactionsTimeWindow.Before) AND 
                         (multiMAXTxn.dbo.AlarmEventTransactionTable.DateTimeOfTxn <= dbo.vwCardTransactionsTimeWindow.After) AND (multiMAXTxn.dbo.AlarmEventTransactionTable.CardID <> 0 AND 
                         multiMAXTxn.dbo.AlarmEventTransactionTable.CardID <> dbo.vwCardTransactionsTimeWindow.CardID)
GO

